#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-puresat-z-internal
version:              0.1
package-name:         puresat
lib-name:             internal
id:                   puresat-0.1-SAnh9P7UMNCmJebgUwg1J-internal
key:                  puresat-0.1-SAnh9P7UMNCmJebgUwg1J-internal
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  fe2cf3c6085442d230276fcdc8a9832f
exposed-modules:
    PureSAT.Assert PureSAT.Base PureSAT.Boost PureSAT.Clause2
    PureSAT.LBool PureSAT.LCG PureSAT.Level PureSAT.LitSet
    PureSAT.LitTable PureSAT.LitVar PureSAT.Main
    PureSAT.PartialAssignment PureSAT.Prim PureSAT.Satisfied
    PureSAT.SparseMaxHeap PureSAT.SparseSet PureSAT.Stats PureSAT.Trail
    PureSAT.Utils PureSAT.VarSet PureSAT.Vec

import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-SAnh9P7UMNCmJebgUwg1J-internal
depends:
    base-4.18.2.1 containers-0.6.7
    primitive-0.9.1.0-CIlU66tAMro5ZKIlpCPDD4

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-puresat-z-dimacs
version:              0.1
package-name:         puresat
lib-name:             dimacs
id:                   puresat-0.1-Ff3y8SoHIgMANzxheng5kf-dimacs
key:                  puresat-0.1-Ff3y8SoHIgMANzxheng5kf-dimacs
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  3bd183c2b14c1b9f274176f819654dc0
exposed-modules:      PureSAT.DIMACS
import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-Ff3y8SoHIgMANzxheng5kf-dimacs
depends:
    base-4.18.2.1 bytestring-0.11.5.3 parsec-3.1.16.1
    puresat-0.1-SAnh9P7UMNCmJebgUwg1J-internal

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 puresat
version:              0.1
visibility:           public
id:                   puresat-0.1-2TOrYkhJ7pCDtbUwqxivDC
key:                  puresat-0.1-2TOrYkhJ7pCDtbUwqxivDC
license:              BSD-3-Clause
copyright:            (c) 2024 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/puresat
synopsis:             Pure Haskell SAT-solver
description:
    SAT Solver implemented in Haskell.

    PureSAT uses DPLL with non-chronological backtracking and learning of binaary clauses.
    Solver is in no-comparison to the state of the art solvers, but it'\''s fast enough to solve sudoku.

category:             Data
abi:                  c370c23662388b7982de8c210a8757ea
exposed:              True
exposed-modules:      Control.Monad.SAT PureSAT
hidden-modules:       EST
import-dirs:          /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/puresat-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/puresat-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puresat
hs-libraries:         HSpuresat-0.1-2TOrYkhJ7pCDtbUwqxivDC
depends:
    base-4.18.2.1 containers-0.6.7
    puresat-0.1-SAnh9P7UMNCmJebgUwg1J-internal

haddock-interfaces:   /usr/share/doc/haskell-puresat/html/puresat.haddock
haddock-html:         /usr/share/doc/haskell-puresat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

